@@ -3,7 +3,7 @@ from typing import Optional
 
 import typer
 
-from .config import get_skill_config
+from .config import get_app_dir
 from .helpers import create_nlp
 
 app = typer.Typer(help='Commands for working with NLP models')
@@ -11,34 +11,22 @@ app = typer.Typer(help='Commands for working with NLP models')
 
 # take name to find app path, otherwise default to cwd
 @app.command()
-def build(
-    name: Optional[str] = typer.Argument(
-        None,
-        help="The name of the skill to build.",
-    ),
-):
+def build(name: Optional[str] = typer.Argument(None, help="The name of the skill to build.")):
     """Build nlp models associated with this skill"""
     app_dir = '.'
     if name:
-        config = get_skill_config(name)
-        app_dir = config['app_dir']
+        app_dir = get_app_dir(name)
 
     nlp = create_nlp(app_dir)
     nlp.build()
 
 
 @app.command()
-def process(
-    name: Optional[str] = typer.Argument(
-        None,
-        help="The name of the skill to send the query to.",
-    ),
-):
+def process(name: Optional[str] = typer.Argument(None, help="The name of the skill to send the query to.")):
     """Run a query through NLP processing"""
     app_dir = '.'
     if name:
-        config = get_skill_config(name)
-        app_dir = config['app_dir']
+        app_dir = get_app_dir(name)
 
     nlp = create_nlp(app_dir)
     nlp.load()
